@@ -140,6 +140,7 @@ void MainWindow::setupActions() //singleton function
     m_combo->setDuplicatesEnabled(false);
 
     KStandardAction::open(this, SLOT(slotScanFolder()), ac);
+    KStandardAction::save(this, SLOT(slotSaveSvg()), ac)->setEnabled(false);
     KStandardAction::quit(this, SLOT(close()), ac);
     KStandardAction::up(this, SLOT(slotUp()), ac);
     KStandardAction::configureToolbars(this, SLOT(configToolbars()), ac);
@@ -180,6 +181,10 @@ void MainWindow::setupActions() //singleton function
     locationAction->setText(i18n("Location Bar"));
     locationAction->setDefaultWidget(m_combo);
 
+    action = ac->action(QStringLiteral("file_save"));
+    action->setText(i18n("Save as SVG..."));
+    action->setToolTip(i18n("Save the current view as an SVG file"));
+
     m_recentScans = new KRecentFilesAction(i18n("&Recent Scans"), ac);
     m_recentScans->setMaxItems(8);
 
@@ -229,6 +234,18 @@ void MainWindow::slotScanHomeFolder()
     slotScanPath(QDir::homePath());
 }
 
+void MainWindow::slotSaveSvg()
+{
+    const QString path = QFileDialog::getSaveFileName(
+        this, i18nc("@title:window", "Save as SVG"), QString(),
+        i18nc("filedialog type filter", "SVG Files (*.svg);;All Files(*)"));
+    if (path.isEmpty()) {
+        return;
+    }
+
+    m_map->saveSvg(path);
+}
+
 void MainWindow::slotScanRootFolder()
 {
     slotScanPath(QDir::rootPath());
@@ -297,6 +314,8 @@ void MainWindow::scanCompleted()
 
     stateChanged(QStringLiteral("scan_complete"));
 
+    action("file_save")->setEnabled(true);
+
     m_combo->lineEdit()->setText(prettyUrl());
 
     if (url.toLocalFile() == QLatin1String("/")) {
@@ -445,6 +464,10 @@ void MainWindow::configFilelight()
     connect(dialog, &SettingsDialog::canvasIsDirty, m_map, &RadialMap::Widget::refresh);
     connect(dialog, &SettingsDialog::mapIsInvalid, m_manager, &ScanManager::emptyCache);
 
+    if (m_summary) {
+        connect(dialog, &SettingsDialog::canvasIsDirty, m_summary, &SummaryWidget::canvasDirtied);
+    }
+
     dialog->show(); //deletes itself
 }
 
@@ -467,8 +490,8 @@ bool MainWindow::start(const QUrl &url)
 
         const QString s = i18n("Scanning: %1", prettyUrl());
         stateChanged(QStringLiteral("scan_started"));
-        emit started(); //as a MainWindow, we have to do this
-        emit setWindowCaption(s);
+        Q_EMIT started(); //as a MainWindow, we have to do this
+        Q_EMIT setWindowCaption(s);
         statusBar()->showMessage(s);
         m_map->hide();
         m_map->invalidate(); //to maintain ui consistency
@@ -508,8 +531,8 @@ void MainWindow::folderScanCompleted(Folder *tree)
     }
     else {
         stateChanged(QStringLiteral("scan_failed"));
-        emit canceled(i18n("Scan failed: %1", prettyUrl()));
-        emit setWindowCaption(QString());
+        Q_EMIT canceled(i18n("Scan failed: %1", prettyUrl()));
+        Q_EMIT setWindowCaption(QString());
 
         statusBar()->clearMessage();
 
@@ -526,7 +549,7 @@ void MainWindow::mapChanged(const Folder *tree)
 {
     //IMPORTANT -> url() has already been set
 
-    emit setWindowCaption(prettyUrl());
+    Q_EMIT setWindowCaption(prettyUrl());
 
     const int fileCount = tree->children();
     const QString text = (fileCount == 0) ?
