@@ -21,19 +21,16 @@
 
 #include "widget.h"
 
-#include "Config.h"
 #include "fileTree.h"
 #include "radialMap.h" //constants
-#include "map.h"
 
 #include <KCursor>        //ctor
-#include <QUrl>
 
 #include <QApplication>   //sendEvent
 #include <QBitmap>        //ctor - finding cursor size
 #include <QCursor>        //slotPostMouseEvent()
+#include <QDebug>
 #include <QTimer>         //member
-#include <QWidget>
 
 
 RadialMap::Widget::Widget(QWidget *parent, bool isSummary)
@@ -97,7 +94,7 @@ void RadialMap::Widget::invalidate()
         update();
 
         //tell rest of Filelight
-        emit invalidated(invalidatedUrl);
+        Q_EMIT invalidated(invalidatedUrl);
     }
 }
 
@@ -124,7 +121,7 @@ RadialMap::Widget::create(const Folder *tree)
     m_tree = tree;
 
     //tell rest of Filelight
-    emit folderCreated(tree);
+    Q_EMIT folderCreated(tree);
 }
 
 void
@@ -160,7 +157,7 @@ RadialMap::Widget::resizeTimeout() //slot
 }
 
 void
-RadialMap::Widget::refresh(int filth)
+RadialMap::Widget::refresh(const Dirty filth)
 {
     //TODO consider a more direct connection
 
@@ -168,21 +165,27 @@ RadialMap::Widget::refresh(int filth)
     {
         switch (filth)
         {
-        case 1:
-            m_focus=nullptr;
+        case Dirty::Layout:
+            m_focus = nullptr;
             m_map.make(m_tree, true); //true means refresh only
             break;
 
-        case 2:
-            m_map.paint(true); //antialiased painting
+        case Dirty::AntiAliasing:
+            m_map.paint();
             break;
 
-        case 3:
-            m_map.colorise(); //FALL THROUGH!
-        case 4:
+        case Dirty::Colors:
+            m_map.colorise();
             m_map.paint();
+            break;
+
+        // At the time of writing only used by the exploded labels
+        // which is redrawn with each paintEvent(), so just need an update()
+        case Dirty::Font:
+            break;
 
         default:
+            qWarning() << "Unhandled filth type" << int(filth);
             break;
         }
 
