@@ -35,6 +35,7 @@
 #include <QTimer>
 
 #include "map.h"
+#include "Config.h" // Dirty
 
 class Folder;
 class File;
@@ -66,12 +67,14 @@ public:
 
     friend class Label; //FIXME badness
 
+    void saveSvg(const QString &path) { m_map.saveSvg(path); }
+
 public Q_SLOTS:
     void zoomIn();
     void zoomOut();
     void create(const Folder*);
     void invalidate();
-    void refresh(int);
+    void refresh(const Dirty filth);
 
 private Q_SLOTS:
     void resizeTimeout();
