@@ -28,12 +28,12 @@
 #include <KJob>
 #include <KIO/Job>     //::mousePressEvent()
 #include <KIO//DeleteJob>
-#include <KIO/JobUiDelegate>
 #include <KMessageBox> //::mousePressEvent()
 #include <QMenu>  //::mousePressEvent()
-#include <KRun>        //::mousePressEvent()
 #include <KToolInvocation>
 #include <QUrl>
+#include <KIO/JobUiDelegate>
+#include <KIO/OpenUrlJob>
 #include <KLocalizedString>
 #include <kio_version.h>
 
@@ -53,6 +53,10 @@
 
 #include <cmath>         //::segmentAt()
 
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 71, 0)
+#include <KIO/OpenUrlJob>
+#endif
+
 void RadialMap::Widget::resizeEvent(QResizeEvent*)
 {
     if (m_map.resize(rect()))
@@ -146,7 +150,7 @@ void RadialMap::Widget::mouseMoveEvent(QMouseEvent *e)
             unsetCursor();
             update();
 
-            emit mouseHover(QString());
+            Q_EMIT mouseHover(QString());
         }
 
         return;
@@ -244,7 +248,7 @@ void RadialMap::Widget::mouseMoveEvent(QMouseEvent *e)
 
     m_tooltip.show();
 
-    emit mouseHover(m_focus->file()->displayPath());
+    Q_EMIT mouseHover(m_focus->file()->displayPath());
     update();
 }
 
@@ -253,7 +257,7 @@ void RadialMap::Widget::enterEvent(QEvent *)
     if (!m_focus) return;
 
     setCursor(Qt::PointingHandCursor);
-    emit mouseHover(m_focus->file()->displayPath());
+    Q_EMIT mouseHover(m_focus->file()->displayPath());
     update();
 }
 
@@ -277,18 +281,19 @@ void RadialMap::Widget::mousePressEvent(QMouseEvent *e)
     const bool isDir = m_focus->file()->isFolder();
 
     // Open file
-    if (e->button() == Qt::MidButton || (e->button() == Qt::LeftButton && !isDir)) {
-        new KRun(url, this, true);
-
+    if (e->button() == Qt::MiddleButton || (e->button() == Qt::LeftButton && !isDir)) {
+        auto *job = new KIO::OpenUrlJob(QUrl(url));
+        job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+        job->start();
         return;
     }
 
     if (e->button() == Qt::LeftButton) {
         if (m_focus->file() != m_tree) {
-            emit activated(url); //activate first, this will cause UI to prepare itself
+            Q_EMIT activated(url); //activate first, this will cause UI to prepare itself
             createFromCache((Folder *)m_focus->file());
         } else if (KIO::upUrl(url) != url) {
-            emit giveMeTreeFor(KIO::upUrl(url));
+            Q_EMIT giveMeTreeFor(KIO::upUrl(url));
         }
 
         return;
@@ -306,6 +311,7 @@ void RadialMap::Widget::mousePressEvent(QMouseEvent *e)
     QAction* openFile = nullptr;
     QAction* copyClipboard = nullptr;
     QAction* deleteItem = nullptr;
+    QAction* doNotScanItem = nullptr;
 
     QMenu popup;
     popup.setTitle(m_focus->file()->displayPath(m_tree));
@@ -321,6 +327,9 @@ void RadialMap::Widget::mousePressEvent(QMouseEvent *e)
             popup.addSeparator();
             centerMap = popup.addAction(QIcon::fromTheme(QStringLiteral( "zoom-in" )), i18n("&Center Map Here"));
         }
+        
+        popup.addSeparator();
+        doNotScanItem = popup.addAction(QIcon::fromTheme(QStringLiteral("list-remove")), i18n("Add to Do &Not Scan List"));
     } else {
         openFile = popup.addAction(QIcon::fromTheme(QStringLiteral("document-open")), i18nc("Scan/open the path of the selected element", "&Open"));
     }
@@ -336,18 +345,31 @@ void RadialMap::Widget::mousePressEvent(QMouseEvent *e)
     QAction* clicked = popup.exec(e->globalPos(), nullptr);
 
     if (openFileManager && clicked == openFileManager) {
-        KRun::runUrl(url, QStringLiteral("inode/directory"), this
-             #if KIO_VERSION >= QT_VERSION_CHECK(5, 31, 0)
-                     , KRun::RunFlags()
-             #endif
-                     );
+        #if KIO_VERSION < QT_VERSION_CHECK(5, 71, 0)
+            KRun::runUrl(url, QStringLiteral("inode/directory"), this
+                 #if KIO_VERSION >= QT_VERSION_CHECK(5, 31, 0)
+                         , KRun::RunFlags()
+                 #endif
+                         );
+        #else // KIO 5.71
+            KIO::OpenUrlJob *job = new KIO::OpenUrlJob(url, QStringLiteral("inode/directory"), this);
+            job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window()));
+            job->start();
+        #endif
     } else if (openTerminal && clicked == openTerminal) {
         KToolInvocation::invokeTerminal(QString(),url.path());
     } else if (centerMap && clicked == centerMap) {
-        emit activated(url); //activate first, this will cause UI to prepare itself
+        Q_EMIT activated(url); //activate first, this will cause UI to prepare itself
         createFromCache((Folder *)m_focus->file());
+    } else if (doNotScanItem && clicked == doNotScanItem) {
+        if (!Config::skipList.contains(Widget::url(m_focus->file()).toLocalFile())) {
+            Config::skipList.append(Widget::url(m_focus->file()).toLocalFile());
+            Config::write();
+        }
     } else if (openFile && clicked == openFile) {
-        new KRun(url, this, true);
+        auto *job = new KIO::OpenUrlJob(url);
+        job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+        job->start();
     } else if (clicked == copyClipboard) {
         QMimeData* mimedata = new QMimeData();
         mimedata->setUrls(QList<QUrl>() << url);
@@ -392,7 +414,7 @@ void RadialMap::Widget::dropEvent(QDropEvent *e)
 {
     QList<QUrl> uriList = KUrlMimeData::urlsFromMimeData(e->mimeData());
     if (!uriList.isEmpty())
-        emit giveMeTreeFor(uriList.first());
+        Q_EMIT giveMeTreeFor(uriList.first());
 }
 
 void RadialMap::Widget::dragEnterEvent(QDragEnterEvent *e)
