@@ -20,13 +20,11 @@
 ***********************************************************************/
 
 #include "remoteLister.h"
-#include "fileTree.h"
 #include "scan.h"
 #include "filelight_debug.h"
 
-#include <KDirLister>
 
-#include <QLinkedList>
+#include <QList>
 #include <QWidget>
 
 namespace Filelight
@@ -39,7 +37,7 @@ namespace Filelight
 
 struct Store {
 
-    typedef QLinkedList<Store*> List;
+    typedef QList<Store*> List;
 
     /// location of the folder
     const QUrl url;
@@ -101,7 +99,7 @@ RemoteLister::~RemoteLister()
 void RemoteLister::onCanceled()
 {
     qCDebug(FILELIGHT_LOG) << "Canceled";
-    emit branchCompleted(nullptr);
+    Q_EMIT branchCompleted(nullptr);
     deleteLater();
 }
 
@@ -112,10 +110,12 @@ void RemoteLister::onCompleted()
     const KFileItemList items = KDirLister::items();
     for (KFileItemList::ConstIterator it = items.begin(), end = items.end(); it != end; ++it)
     {
-        if (it->isDir())
+        if (it->isDir()) {
             m_store->stores += new Store(it->url(), it->name(), m_store);
-        else
+        } else {
             m_store->folder->append(it->name().toUtf8().constData(), it->size());
+            m_manager->m_totalSize += it->size();
+        }
 
         m_manager->m_files++;
     }
@@ -153,7 +153,7 @@ void RemoteLister::onCompleted()
         qCDebug(FILELIGHT_LOG) << "I think we're done";
 
         Q_ASSERT(m_root == m_store);
-        emit branchCompleted(m_store->folder);
+        Q_EMIT branchCompleted(m_store->folder);
 
         deleteLater();
     }
