@@ -20,11 +20,9 @@
 ***********************************************************************/
 
 #include "settingsDialog.h"
-#include "Config.h"
 
 #include <KLocalizedString>
 #include <QRadioButton>
-#include <QCloseEvent>
 #include <QDir>
 #include <KMessageBox>
 #include <QFileDialog>
@@ -67,14 +65,11 @@ SettingsDialog::SettingsDialog(QWidget *parent) : QDialog(parent)
     connect(m_schemaGroup, static_cast<void (QButtonGroup::*)(QAbstractButton *)>(&QButtonGroup::buttonClicked), this, &SettingsDialog::changeScheme);
 
     connect(contrastSlider, &QSlider::valueChanged, this, &SettingsDialog::changeContrast);
-    connect(contrastSlider, &QSlider::sliderReleased, this, &SettingsDialog::slotSliderReleased);
 
     connect(scanAcrossMounts, &QCheckBox::toggled, this, &SettingsDialog::startTimer);
     connect(dontScanRemoteMounts, &QCheckBox::toggled, this, &SettingsDialog::startTimer);
-    connect(dontScanRemovableMedia, &QCheckBox::toggled, this, &SettingsDialog::startTimer);
     connect(scanAcrossMounts, &QCheckBox::toggled, this, &SettingsDialog::toggleScanAcrossMounts);
     connect(dontScanRemoteMounts, &QCheckBox::toggled, this, &SettingsDialog::toggleDontScanRemoteMounts);
-    connect(dontScanRemovableMedia, &QCheckBox::toggled, this, &SettingsDialog::toggleDontScanRemovableMedia);
 
     connect(useAntialiasing, &QCheckBox::toggled, this, &SettingsDialog::toggleUseAntialiasing);
     connect(varyLabelFontSizes, &QCheckBox::toggled, this, &SettingsDialog::toggleVaryLabelFontSizes);
@@ -105,10 +100,8 @@ void SettingsDialog::reset()
     //tab 1
     scanAcrossMounts->setChecked(Config::scanAcrossMounts);
     dontScanRemoteMounts->setChecked(!Config::scanRemoteMounts);
-    dontScanRemovableMedia->setChecked(!Config::scanRemovableMedia);
 
     dontScanRemoteMounts->setEnabled(Config::scanAcrossMounts);
-    //  dontScanRemovableMedia.setEnabled(Config::scanAcrossMounts);
 
     m_listBox->clear();
     m_listBox->addItems(Config::skipList);
@@ -143,7 +136,6 @@ void SettingsDialog::toggleScanAcrossMounts(bool b)
     Config::scanAcrossMounts = b;
 
     dontScanRemoteMounts->setEnabled(b);
-    //dontScanRemovableMedia.setEnabled(b);
 }
 
 void SettingsDialog::toggleDontScanRemoteMounts(bool b)
@@ -151,11 +143,6 @@ void SettingsDialog::toggleDontScanRemoteMounts(bool b)
     Config::scanRemoteMounts = !b;
 }
 
-void SettingsDialog::toggleDontScanRemovableMedia(bool b)
-{
-    Config::scanRemovableMedia = !b;
-}
-
 
 
 void SettingsDialog::addFolder()
@@ -206,44 +193,37 @@ void SettingsDialog::changeScheme(QAbstractButton *button)
     if (button) {
         const int s = m_schemaGroup->id(button);
         Config::scheme = (Filelight::MapScheme)s;
-        emit canvasIsDirty(1);
+        Q_EMIT canvasIsDirty(Dirty::Colors);
     }
 }
 void SettingsDialog::changeContrast(int c)
 {
     Config::contrast = c;
-    emit canvasIsDirty(3);
+    Q_EMIT canvasIsDirty(Dirty::Colors);
 }
 void SettingsDialog::toggleUseAntialiasing(bool b)
 {
     Config::antialias = b;
-    emit canvasIsDirty(2);
+    Q_EMIT canvasIsDirty(Dirty::AntiAliasing);
 }
 void SettingsDialog::toggleVaryLabelFontSizes(bool b)
 {
     Config::varyLabelFontSizes = b;
     minFontPitchLabel->setEnabled(b);
     minFontPitch->setEnabled(b);
-    emit canvasIsDirty(0);
+    Q_EMIT canvasIsDirty(Dirty::Font);
 }
 void SettingsDialog::changeMinFontPitch(int p)
 {
     Config::minFontPitch = p;
-    emit canvasIsDirty(0);
+    Q_EMIT canvasIsDirty(Dirty::Font);
 }
 void SettingsDialog::toggleShowSmallFiles(bool b)
 {
     Config::showSmallFiles = b;
-    emit canvasIsDirty(1);
+    Q_EMIT canvasIsDirty(Dirty::Layout);
 }
 
-
-void SettingsDialog::slotSliderReleased()
-{
-    emit canvasIsDirty(2);
-}
-
-
 void SettingsDialog::reject()
 {
     //called when escape is pressed
